@@ -24,7 +24,7 @@
 #include <glib.h>
 #include <gio/gio.h>
 
-#include "result.h"
+#include <librepo/result.h>
 
 G_BEGIN_DECLS
 
@@ -38,11 +38,11 @@ G_BEGIN_DECLS
  */
 typedef struct _LrHandle LrHandle;
 
-#ifdef WITH_ZCHUNK
+#if 0
 /** Define LRO_SUPPORTS_CACHEDIR so clients can check for this feature at build
  * time */
 #define LRO_SUPPORTS_CACHEDIR
-#endif /* WITH_ZCHUNK */
+#endif /* 0 */
 
 /** LRO_FASTESTMIRRORMAXAGE default value */
 #define LRO_FASTESTMIRRORMAXAGE_DEFAULT     2592000L // 30 days
